@@ -8,6 +8,7 @@
 #' @param check.between.groups \code{logical}; if \code{TRUE}, the function will output a named list containing the metric level and a logical indicating whether the metric can be used between groups or not. If \code{FALSE} (default) the function only outputs the metric level.
 #' @param data.dim optional, two \code{numeric} values for the dimensions of the matrix to run the test function testing. If missing, a default 5 rows by 4 columns matrix is used.
 #' @param tree optional, a \code{phylo} object.
+#' @param covar \code{logical}, whether to treat the metric as applied the a \code{data$covar} component (\code{TRUE}) or not (\code{FALSE}; default).
 #'
 #' @details
 #' This function tests:
@@ -50,7 +51,7 @@
 #' @seealso \code{\link{dispRity}}, \code{\link{dispRity.metric}}.
 #'
 #' @author Thomas Guillerme
-make.metric <- function(fun, ..., silent = FALSE, check.between.groups = FALSE, data.dim, tree = NULL) {
+make.metric <- function(fun, ..., silent = FALSE, check.between.groups = FALSE, data.dim, tree = NULL, covar = FALSE) {
     ## Sanitizing
     ## fun
     check.class(fun, c("function", "standardGeneric"), report = 1)
@@ -70,6 +71,11 @@ make.metric <- function(fun, ..., silent = FALSE, check.between.groups = FALSE,
     }
     matrix <- matrix(rnorm(data.dim[1]*data.dim[2]), data.dim[1], data.dim[2])
     matrix_text <- paste0("matrix(rnorm(",data.dim[1],"*",data.dim[2],"), ",data.dim[1], ", ",data.dim[2], ")")
+    
+    if(covar) {
+        matrix <- list(VCV = matrix, loc = diag(matrix))
+        matrix_text <- ""
+    }
 
     ## Testing the metric
     test <- NULL
@@ -82,11 +88,19 @@ make.metric <- function(fun, ..., silent = FALSE, check.between.groups = FALSE,
     is_between.groups <- all(c("matrix", "matrix2") %in% arguments)
     is_phylo <- "tree" %in% arguments
 
+    if(is_between.groups) {
+        ## Create a matrix2
+        matrix2 <- matrix(rnorm(data.dim[1]*data.dim[2]), data.dim[1], data.dim[2])        
+        if(covar) {
+            matrix2 <- list(VCV = matrix2, loc = diag(matrix2))
+        }
+    }
+
     ## Skip the dots if the dots has a tree argument
     if(!is_phylo) {
         ## Test the metric
         if(is_between.groups) {
-            test <- try(fun(matrix = matrix, matrix2 = matrix, ...), silent = TRUE)
+            test <- try(fun(matrix = matrix, matrix2 = matrix2, ...), silent = TRUE)
         } else {
             test <- try(fun(matrix, ...), silent = TRUE)
         }
@@ -107,7 +121,7 @@ make.metric <- function(fun, ..., silent = FALSE, check.between.groups = FALSE,
         rownames(matrix) <- c(tree$tip.label, tree$node.label)
         ## Test the metric
         if(is_between.groups) {
-            test <- try(fun(matrix = matrix, matrix2 = matrix, tree = tree, ...), silent = TRUE)
+            test <- try(fun(matrix = matrix, matrix2 = matrix2, tree = tree, ...), silent = TRUE)
         } else {
             test <- try(fun(matrix, tree = tree, ...), silent = TRUE)
         }        
