@@ -1,8 +1,8 @@
 ## Get the disparity characteristics
 get.data.params <- function(data) {
     return(list(
-        "distribution"   = ifelse(length(data$disparity[[1]]$elements) != 1, TRUE, FALSE),
-        "bootstrap"      = ifelse(!is.null(data$call$bootstrap), TRUE, FALSE),
+        "distribution"   = length(data$disparity[[1]]$elements) != 1,
+        "bootstrap"      = !is.null(data$call$bootstrap) && data$call$bootstrap[[2]] != "covar",
         "rarefaction"    = data$call$bootstrap[[3]],
         "between.groups" = data$call$disparity$metrics$between.groups,
         "elements"       = names(data$disparity)
@@ -69,21 +69,21 @@ get.plot.params <- function(data, data_params, cent.tend, quantiles, rarefaction
             ## Getting the observed or bootstrapped data
             if(data_params$bootstrap && !observed_args$observed) {
                 ## Getting the bootstrapped data
-                box_data <- unlist(extract.dispRity(data, observed = FALSE), recursive = FALSE)
+                box_data <- unlist(get.disparity(data, observed = FALSE), recursive = FALSE)
             } else {
                 if(data_params$distribution || data_params$between.groups) {
-                    box_data <- extract.dispRity(data, observed = TRUE)
+                    box_data <- lapply(get.disparity(data, observed = TRUE, concatenate = FALSE), c)
                 } else {
                     if(ncol(disparity$data) == 1) {
-                        box_data <- extract.dispRity(data, observed = TRUE)
+                        box_data <- get.disparity(data, observed = TRUE)
                     } else {
-                        box_data <- unlist(extract.dispRity(data, observed = FALSE), recursive = FALSE)
+                        box_data <- unlist(get.disparity(data, observed = FALSE), recursive = FALSE)
                     }
                 }
             }
         } else {
             ## Find the correct rarefaction level
-            box_data <- unlist(extract.dispRity(data, observed = FALSE, rarefaction = rarefaction_level), recursive = FALSE)
+            box_data <- unlist(get.disparity(data, observed = FALSE, rarefaction = rarefaction_level), recursive = FALSE)
         }
         ## Updating the disparity data part
         if(data_params$between.groups) {
@@ -251,6 +251,39 @@ get.plot.params <- function(data, data_params, cent.tend, quantiles, rarefaction
     return(list("disparity" = disparity, "helpers" = helpers, "options" = options, "observed_args" = observed_args, "elements_args" = elements_args))
 }
 
+## Get dots options
+# @param dots ...
+# @param args the list of arguments to be affected by dots
+# @param name the argument name
+# @param default an optional default argument (default is NULL)
+# @param fun an optional suffix argument for the function to be used (default is NULL)
+get.dots <- function(dots, args, name, default = NULL, fun = NULL) {
+    ## Override the name without fun in dots
+    if(!is.null(fun) && !is.null(names(dots))) {
+        name_plus <- paste0(fun, ".", name)
+        if(name_plus %in% names(dots)) {
+            dots[[name]] <- dots[[name_plus]]
+        }
+    } 
+
+    ## Fill in the dots in the arguments list
+    if(!is.null(default)) {
+        if(is.null(dots[[name]])) {
+            ## Set the default
+            args[[name]] <- default
+        } else {
+            ## Use the dots
+            args[[name]] <- dots[[name]]
+        }
+    } else {
+        ## Use the dots
+        if(!is.null(dots[[name]])) {
+            args[[name]] <- dots[[name]]
+        }
+    }
+    return(args)
+}
+
 ## Handle the shift argument
 get.shift <- function(add, plot_params) {
     ## Set the shift parameter (for add)
@@ -660,6 +693,8 @@ plot.rarefaction <- function(plot_params, data_params, data) {
 ## Plotting a space preview
 plot.preview <- function(data, specific.args, ...) {
 
+    dots <- list(...)
+
     ## The "ggplot" colours
     gg.color.hue <- function(n) {
         grDevices::hcl(h = seq(15, 375, length = n + 1), l = 65, c = 100)[1:n]
@@ -669,24 +704,20 @@ plot.preview <- function(data, specific.args, ...) {
     }
 
     ## Set up the specific args
-    if(is.null(specific.args$matrix)) {
-        specific.args$matrix <- c(1:length(data$matrix))
-    }
-    if(is.null(specific.args$dimensions)) {
-        specific.args$dimensions <- c(1,2)
-    }
-    if(is.null(specific.args$legend)) {
+    specific.args <- get.dots(specific.args, specific.args, "matrix", c(1:length(data$matrix)))
+    specific.args <- get.dots(specific.args, specific.args, "dimensions", c(1:2))
+    
+    ## Plot the legend?
+    if(is.null(dots$legend)) {
         plot_legend <- TRUE
-        legend_args <- list()
+        dots$legend <- NULL
     } else {
-        if(is(specific.args$legend, "logical")) {
-            plot_legend <- specific.args$legend
-            legend_args <- list()
-        } else {
-            plot_legend <- TRUE
-            legend_args <- specific.args$legend
+        if(is.logical(dots$legend)) {
+            plot_legend <-dots$legend
+            dots$legend <- NULL
         }
     }
+
     if(is.null(specific.args$tree) || is.null(data$tree[[1]])) {
         ## Don't plot trees
         plot_trees <- FALSE
@@ -705,50 +736,45 @@ plot.preview <- function(data, specific.args, ...) {
     }
 
     ## Capturing the dots options
-    plot_args <- list(x = NULL, y = NULL, ...)
+    plot_args <- c(list(x = NULL, y = NULL), dots)
+    ## Removing specific args from dots
+    remove <- c(grep(c("legend"), names(plot_args)), grep(c("lines"), names(plot_args)), grep(c("points"), names(plot_args)))
+    plot_args[remove] <- NULL
 
     ## Getting the loadings
     loading <- apply(do.call(rbind, lapply(data$matrix[specific.args$matrix], function(matrix) apply(matrix, 2, var, na.rm = TRUE))), 2, mean)
     loading <- round(loading/sum(loading)*100, 2)
 
     ## Setting the labels
-    if(is.null(plot_args$xlab)) {
-        plot_args$xlab <- paste0("Dimension ", specific.args$dimensions[1], " (", loading[specific.args$dimensions[1]], "%)")
-    }
-    if(is.null(plot_args$ylab)) {
-        plot_args$ylab <- paste0("Dimension ", specific.args$dimensions[2], " (", loading[specific.args$dimensions[2]], "%)")
-    }
+    plot_args <- get.dots(dots, plot_args, "xlab", paste0("Dimension ", specific.args$dimensions[1], " (", loading[specific.args$dimensions[1]], "%)"))
+    plot_args <- get.dots(dots, plot_args, "ylab", paste0("Dimension ", specific.args$dimensions[2], " (", loading[specific.args$dimensions[2]], "%)"))
 
     ## Setting plot limits
     plot_lim <- range(unlist(lapply(data$matrix[specific.args$matrix], function(matrix, dim) c(matrix[, dim]), dim = specific.args$dimensions)))
-    if(is.null(plot_args$xlim)) {
-        plot_args$xlim <- plot_lim
-    }
-    if(is.null(plot_args$ylim)) {
-        plot_args$ylim <- plot_lim
-    }
+    plot_args <- get.dots(dots, plot_args, "xlim", plot_lim)
+    plot_args <- get.dots(dots, plot_args, "ylim", plot_lim)
 
     ## Get the number of colour groups
     n_groups <- length(data$subsets)
     n_groups <- ifelse(n_groups == 0, 1, n_groups)
 
     ## Setting the colours
-    if(is.null(plot_args$col)) {
-        if(n_groups == 1) {
-            plot_args$col <- "black"
-        } else {
-            if(data$call$subsets[[1]] == "customised") {
-                plot_args$col <- gg.color.hue(n_groups)
-            } else {
-                plot_args$col <- grDevices::heat.colors(n_groups+2)[1:n_groups]
-            }
-        }
-    }
+    plot_args <- get.dots(dots, plot_args, "col",
+            default =
+                ## Toggle between different defaults
+                if(n_groups == 1) {
+                    "black"
+                } else {
+                    if(data$call$subsets[[1]] %in% c("customised", "covar")) {
+                        gg.color.hue(n_groups)
+                    } else {
+                        grDevices::heat.colors(n_groups+2)[1:n_groups]
+                    }
+                }
+    , fun = "points")
 
     ## Setting the pch
-    if(is.null(plot_args$pch)) {
-        plot_args$pch <- 19
-    }
+    plot_args <- get.dots(dots, plot_args, "pch", 19, fun = "points")
     if(length(plot_args$pch) != n_groups) {
         plot_args$pch <- rep(plot_args$pch, n_groups)
     }
@@ -761,7 +787,7 @@ plot.preview <- function(data, specific.args, ...) {
         subsets <- lapply(data$subsets,`[[`, "elements")
         ## Make an empty classifier
         classifier <- rep(NA, nrow(data$matrix[[1]]))
-        for(class in 1:n_groups) {
+        for(class in match(sort(unlist(lapply(subsets, length)), decreasing = TRUE), unlist(lapply(subsets, length)))) {
             ## Store the selected subsets in the classifier (potentially overriding)
             if(dim(subsets[[1]])[2] == 1) {
                 classifier[c(subsets[[class]])] <- class 
@@ -787,17 +813,13 @@ plot.preview <- function(data, specific.args, ...) {
 
         ## Get the lines arguments
         lines_args <- plot_args
-        lines_args$col <- "grey"
+        lines_args <- get.dots(dots, lines_args, "col", "grey", fun = "lines")
         if(length(specific.args$tree) > 1) {
             lines_args$col <- make.transparent(lines_args$col, levels = length(specific.args$tree))
         }
-        if(is.null(lines_args$lwd)) {
-            lines_args$lwd <- 1
-        }
-        if(is.null(lines_args$lty)) {
-            lines_args$lty <- 1
-        }
-
+        lines_args <- get.dots(dots, lines_args, "lwd", 1, fun = "lines")
+        lines_args <- get.dots(dots, lines_args, "lty", 1, fun = "lines")
+        
         ## Plotting each tree
         for(one_tree in specific.args$tree) {
 
@@ -811,7 +833,7 @@ plot.preview <- function(data, specific.args, ...) {
             ## Selecting the origin points for the tree
             points_data <- data_matrix[, specific.args$dimensions][c(data$tree[[one_tree]]$tip.label, data$tree[[one_tree]]$node.label), ] 
             ## Plotting all the edges
-            apply(data$tree[[one_tree]]$edge, 1, plot.edge,
+            silent <- apply(data$tree[[one_tree]]$edge, 1, plot.edge,
                   points_data = points_data,
                   params = lines_args)
         }
@@ -827,6 +849,7 @@ plot.preview <- function(data, specific.args, ...) {
         ## Add the points per matrix
         point_args$x <- data$matrix[[specific.args$matrix[matrix]]][, specific.args$dimensions[1]]
         point_args$y <- data$matrix[[specific.args$matrix[matrix]]][, specific.args$dimensions[2]]
+
         ## Call the points
         do.call(points, point_args)
     }
@@ -835,21 +858,15 @@ plot.preview <- function(data, specific.args, ...) {
     if(n_groups > 1 && plot_legend) {
 
         ## Set the legend arguments
-        if(is.null(legend_args$x)) {
-            legend_args$x <- "topright"
-        }
-        if(is.null(legend_args$legend)) {
-            legend_args$legend <- names(data$subsets)
-        }
-        if(is.null(legend_args$col)) {
-            legend_args$col <- col_order
-        }
-        if(is.null(legend_args$pch)) {
-            legend_args$pch <- pch_order
-        }
-        if(is.null(legend_args$cex)) {
-            legend_args$cex <- 0.666
-        }
+        legend_args <- list()
+        legend_args <- get.dots(dots, legend_args, "x", "topright", fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "y", fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "legend", names(data$subsets), fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "col", col_order, fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "pch", pch_order, fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "cex", 2/3, fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "bg", NULL, fun = "legend")
+
         ## Add the legend
         do.call(legend, legend_args)
     }
@@ -859,27 +876,35 @@ plot.preview <- function(data, specific.args, ...) {
 }
 
 ## The following is a modified version of plot.randtest from ade4 v1.4-3
-plot.randtest <- function(data_sub, ...) {
-    plot_args <- list(...)
+plot.randtest <- function(plot_data) {
+    
+    ## Extracting the elements
+    dots <- plot_data$dots
+    data_sub <- plot_data$data_sub 
 
-    ## Extracting the specific args
-    specific_args <- plot_args$specific.args
-    plot_args$specific.args <- NULL
+    ## Plot the legend or not
+    if(is.null(dots$legend)) {
+        plot_legend <- TRUE
+        dots$legend <- NULL
+    } else {
+        if(is.logical(dots$legend)) {
+            plot_legend <-dots$legend
+            dots$legend <- NULL
+        }
+    }
 
     ## Add the histogram data
-    plot_args$x <- data_sub$plot$hist
+    plot_args <- c(list(x = data_sub$plot$hist), dots)
+    ## Removing specific args from dots
+    remove <- c(grep(c("legend"), names(plot_args)), grep(c("lines"), names(plot_args)), grep(c("points"), names(plot_args)))
+    plot_args[remove] <- NULL   
 
     ## Plot arguments
-    if(is.null(plot_args$xlim)) {
-        plot_args$xlim <- data_sub$plot$xlim
-    }
-    if(is.null(plot_args$ylim)) {
-        plot_args$ylim <- c(0, max(data_sub$plot$hist$count))
-    }
-    if(is.null(plot_args$col)) {
-        plot_args$col <- "grey"
-    }
-
+    plot_args <- get.dots(dots, plot_args, "xlim", data_sub$plot$xlim)
+    plot_args <- get.dots(dots, plot_args, "ylim", c(0, max(data_sub$plot$hist$count)))
+    plot_args <- get.dots(dots, plot_args, "col", "grey")
+    plot_args <- get.dots(dots, plot_args, "main")
+    
     ## Plotting the simulated data
     do.call(plot, plot_args)
 
@@ -887,73 +912,51 @@ plot.randtest <- function(data_sub, ...) {
     observed <- data_sub$obs
 
     ## Adding the observed data
-    lines(c(observed, observed), c(plot_args$ylim[2]/2, 0))
-    points(observed, plot_args$ylim[2]/2, pch = 18, cex = 2)
-
-    ## Setting the specific args for the legend
-    if(is.null(specific_args$legend)) {
-        plot_legend <- TRUE
-    } else {
-        if(is(specific_args$legend, "logical")) {
-            plot_legend <- specific_args$legend
-        } else {
-            plot_legend <- TRUE
-        }
-    }
+    lines_args <- list(x = c(observed, observed), y = c(plot_args$ylim[2]/2, 0))
+    lines_args <- get.dots(dots, lines_args, "col", "black", fun = "lines")
+    lines_args <- get.dots(dots, lines_args, "lty", 1, fun = "lines")
+    lines_args <- get.dots(dots, lines_args, "lwd", 1, fun = "lines")
+    do.call(lines, lines_args)
+    point_args <- list(x = observed, y = plot_args$ylim[2]/2)
+    point_args <- get.dots(dots, point_args, "col", "black", fun = "points")
+    point_args <- get.dots(dots, point_args, "pch", 18, fun = "points")
+    point_args <- get.dots(dots, point_args, "cex", 2, fun = "points")
+    do.call(points, point_args)
 
     ## Adding the legend (test results)
     if(plot_legend) {
-        ## Initialise the legend arguments
-        if(is.null(specific_args)) {
-            legend_args <- list()    
-        } else {
-            legend_args <- specific_args$legend
-        }
-        
-        ## Set the default legend arguments
-        if(is.null(legend_args$x)) {
-            legend_args$x <- "topleft"
-        }
-        if(is.null(legend_args$bty)) {
-            legend_args$bty <- "n"
-        }
-        if(is.null(legend_args$legend)) {
-            legend_args$legend <- c("p-value", round(data_sub$pvalue, 5))
-        }
-        if(is.null(legend_args$cex)) {
-            legend_args$cex <- 0.7
-        }
-        if(is.null(legend_args$adj)) {
-            legend_args$adj <- 0.2
-        }
+        ## Set the legend arguments
+        legend_args <- list()
+        legend_args <- get.dots(dots, legend_args, "x", "topleft", fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "y", fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "bty", "n", fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "legend", c("p-value", round(data_sub$pvalue, 5)), fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "cex", 2/3, fun = "legend")
+        legend_args <- get.dots(dots, legend_args, "adj", 0.2, fun = "legend")
+        ## Add the legend
         do.call(legend, legend_args)
     }
 }
 
 ## The following is a modified version of dtt plots (from https://github.com/mwpennell/geiger-v2/blob/master/R/disparity.R)
 plot.dtt <- function(data, quantiles, cent.tend, density, ...) {
-    plot_args <- list(...)
+    dots <- list(...)
+
+    plot_args <- dots
+    remove <- c(grep(c("polygon"), names(plot_args)), grep(c("lines"), names(plot_args)))
+    plot_args[remove] <- NULL   
 
     ## Set the default options
-    if(is.null(plot_args$ylim)) {
-        ## The base y-limit
-        plot_args$ylim <- c(range(pretty(data$dtt)))
-
-        ## Add the simulation (if exist)
-        if(!is.null(data$sim)) {
-            plot_args$ylim <- range(c(plot_args$ylim , range(data$sim)))
-        }
-    }
-    if(is.null(plot_args$xlab)) {
-        plot_args$xlab <- "scaled time"
-    }
-    if(is.null(plot_args$ylab)) {
-        plot_args$ylab <- paste0("scaled ", as.character(data$call[[3]]))
-    }
-    if(is.null(plot_args$col)) {
-        colfun <- grDevices::colorRampPalette(c("lightgrey", "grey"))
-        plot_args$col <- c("black", colfun(length(quantiles)))
-    }
+    plot_args <- get.dots(plot_args, plot_args, "ylim", 
+            if(!is.null(data$sim)) {
+                c(range(pretty(c(data$dtt, data$sim))))
+            } else {
+                c(range(pretty(data$dtt)))
+            }
+        )
+    plot_args <- get.dots(plot_args, plot_args, "xlab", "scaled time")
+    plot_args <- get.dots(plot_args, plot_args, "ylab", paste0("scaled ", paste(as.character(data$call[[3]]), collapse = " ")))
+    plot_args <- get.dots(plot_args, plot_args, "col", c("black", grDevices::colorRampPalette(c("lightgrey", "grey"))(length(quantiles))))
 
     ## Add the data for the plot args
     plot_args$x <- data$times
@@ -992,37 +995,39 @@ plot.dtt <- function(data, quantiles, cent.tend, density, ...) {
 
         ## Plotting the polygons for each quantile
         for(cis in 1:n_quantiles) {
-            xx <- c(data$times, rev(data$times))
-            yy <- c(quantiles_values[(n_quantiles*2) - (cis-1), ], rev(quantiles_values[cis ,]))
-            polygon(xx, yy, col = plot_args$col[cis+1], border = FALSE, density = density)
+            poly_args <- list(x = c(data$times, rev(data$times)),
+                              y = c(quantiles_values[(n_quantiles*2) - (cis-1), ], rev(quantiles_values[cis ,])))
+            poly_args <- get.dots(dots, poly_args, "border", FALSE, "polygon")
+            poly_args <- get.dots(dots, poly_args, "density", density, "polygon")
+            poly_args$col <- plot_args$col[cis+1]
+            do.call(polygon, poly_args)
         }
 
         ## Add the central tendency
-        lines(data$times, cent_tend_values, col = plot_args$col[1], lty = 2)
+        lines_args <- list(x = data$times,
+                          y = cent_tend_values)
+        lines_args <- get.dots(dots, lines_args, "lty", 2, "lines")
+        lines_args <- get.dots(dots, lines_args, "lwd", 1, "lines")
+        lines_args <- get.dots(dots, lines_args, "col", plot_args$col[1], "lines")
+        do.call(lines, lines_args)
     }
 
     ## Add the observed disparity
-    line_args <- plot_args
-    line_args$type <- NULL
-    line_args$col <- plot_args$col[1]
-    if(is.null(plot_args$lwd)) {
-        line_args$lwd <- 1.5
-    }
-    do.call(lines, line_args)
+    lines_args <- plot_args
+    lines_args$type <- NULL
+    lines_args <- get.dots(dots, lines_args, "lty", 1, "lines")
+    lines_args <- get.dots(dots, lines_args, "lwd", 1.5, "lines")
+    lines_args <- get.dots(dots, lines_args, "col", plot_args$col[1], "lines")
+    do.call(lines, lines_args)
 }
 
 ## Plotting model tests results
 plot.model.test <- function(data, ...) {
 
     plot_args <- list(...)
-
     ## Set the default plotting arguments
-    if(is.null(plot_args$ylab)) {
-        plot_args$ylab <- "weighted AIC"
-    }
-    if(is.null(plot_args$col)) {
-        plot_args$col <- "grey"
-    }
+    plot_args <- get.dots(plot_args, plot_args, "ylab", "weighted AIC", "barplot")
+    plot_args <- get.dots(plot_args, plot_args, "col", "grey", "barplot")
 
     ## Extracting the weighted aicc
     aic_values <- data$aic.models[, 3]
@@ -1220,7 +1225,6 @@ plot.test.metric <- function(data, specific.args, ...) {
         legend_args_1 <- legend_args_2 <- legend_args_2_base <- legend_args
     }
 
-
     ## Separating the data
     plot_groups <- list()
     for(group in 1:length(unique(group_plot))) {
@@ -1368,8 +1372,12 @@ plot.test.metric <- function(data, specific.args, ...) {
                 ## Making a new subset without the negatives
                 step_preview$subsets$negatives$elements <- matrix((1:nrow(step_preview$matrix[[1]]))[-c(step_preview$subsets[[1]]$elements)], ncol = 1)
 
+                ## Rename the subsets
+                names(step_preview$subsets)[2] <- as.character(100 - as.numeric(names(step_preview$subsets)[1]))
+
                 ## Default title
                 step_name <- names(step_preview$subsets)[1]
+
                 ## Selecting the colours and the title
                 if(names(data$saved_steps)[[shift]] == "random") {
                     select_col <- c(plot_args$col[1], "grey")
@@ -1381,7 +1389,7 @@ plot.test.metric <- function(data, specific.args, ...) {
                                     
                 ## Plotting the shift preview
                 par(mar = mar_base)
-                plot.dispRity(step_preview, type = "preview", col = select_col, specific.args = list(legend = FALSE), main = step_name,xaxt = xaxts[step], yaxt = yaxts[step])
+                plot.dispRity(step_preview, type = "preview", legend = TRUE, col = select_col, main = step_name,xaxt = xaxts[step], yaxt = yaxts[step], legend.bg = "white")
             }
         }
         ## Reset the default plot margins
@@ -1476,4 +1484,64 @@ plot.axes <- function(data, ...) {
     }
     par(op_tmp)
     return(invisible())
+}
+
+## Plot projections
+plot.projection <- function(data, specific.args, cent.tend, ...) {
+
+    dots <- list(...)
+
+    ## Check whether to do a correlation plot or not
+    do_correlation_plot <- !is.null(specific.args$correlation.plot)
+    
+    ## Don't do a correlation plot
+    if(!do_correlation_plot) {
+        ## Find the number of elements to plot
+        n_plots <- length(data)
+        ## Open the plot window
+        par(mfrow = c(1,n_plots))
+        ## Shmart plot
+        shmart.plot <- function(one_data, ylabs, ...) {
+            dots <- list(...)
+            if(is.null(dots$ylab)) {
+                plot.dispRity(one_data, ylab = ylabs, ...)
+            } else {
+                plot.dispRity(one_data, ...)
+            }
+        }
+        ## Plot all that
+        if(is.null(dots$ylab)) {
+            ylab <- names(data)
+        } else {
+            ylab <- dots$ylab
+            dots$ylab <- NULL
+        }
+        silent <- mapply(shmart.plot, data, ylabs = ylab, MoreArgs = list(...))
+    
+    } else {
+
+        ## Get the central tendencies
+        if(!all(specific.args$correlation.plot %in% names(data)) && length(specific.args$correlation.plot) != 2) {
+            stop(paste0("correlation.plot argument must contain 2 elements from data (data contains: ", paste(names(data), collapse = ", "), ")."))
+        }
+
+        ## Remove the phylogeny part (if exists)
+        if(n.subsets(data[[1]]) > 1) {
+            ## Check if any subset is the size of the entire matrix
+            global <- which(size.subsets(data[[1]]) == nrow(data[[1]]$matrix[[1]]))
+            if(length(global) != 0) {
+                nsets <- 1:n.subsets(data[[1]])
+                data <- lapply(data, function(x, subsets) get.subsets(x, subsets = subsets), subsets = nsets[-global])
+            }
+        }
+
+        ## Get the central tendencies
+        var1 <- unlist(lapply(lapply(data[[specific.args$correlation.plot[1]]]$disparity, function(X, type) return(X$elements)), function(X, fun) apply(X, 1, fun), fun = cent.tend))
+        var2 <- unlist(lapply(lapply(data[[specific.args$correlation.plot[2]]]$disparity, function(X, type) return(X$elements)), function(X, fun) apply(X, 1, fun), fun = cent.tend))
+        plot_data <- cbind(var1, var2)
+        colnames(plot_data) <- specific.args$correlation.plot
+
+        ## Plot the results
+        plot(plot_data, ...)
+    }
 }
\ No newline at end of file
